==> af-common-liuli-1.1.7.2-sources.jar: com/af/v4/system/common/liuli/service/LiuLiMonitorService.java <==
package com.af.v4.system.common.liuli.service;

import com.af.v4.system.common.core.constant.CacheConstants;
import com.af.v4.system.common.core.utils.ApplicationUtils;
import com.af.v4.system.common.core.utils.StringUtils;
import com.af.v4.system.common.liuli.utils.LiuLiUtil;
import com.af.v4.system.common.plugins.http.RestAsyncTools;
import com.af.v4.system.common.redis.RedisService;
import org.json.JSONObject;
import org.springframework.stereotype.Service;

/**
 * 琉璃-监控服务
 *
 * @author Mr.river
 */
@Service
public class LiuLiMonitorService {
    /**
     * 上报应用错误日志
     */
    private static final String UPLOAD_ERROR_LOG_PATH = "/liuli/logic/uploadErrorLog";

    private final LiuLiUtil liuLiUtil;
    private final RedisService redisService;
    private final ApplicationUtils applicationUtils;

    public LiuLiMonitorService(LiuLiUtil liuLiUtil, RedisService redisService, ApplicationUtils applicationUtils) {
        this.liuLiUtil = liuLiUtil;
        this.redisService = redisService;
        this.applicationUtils = applicationUtils;
    }

    /**
     * 上报错误日志
     */
    public void uploadLogicErrorLog(JSONObject operLog, Exception e) {
        String tenantUUID = redisService.get(CacheConstants.TENANT_UUID_KEY);
        //调用琉璃中心需传递的参数
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("tenantUUID", tenantUUID);
        jsonObject.put("applicationName", applicationUtils.getApplicationName());
        jsonObject.put("environment", applicationUtils.getEnvType().getValue());
        jsonObject.put("method", operLog.opt("f_method"));
        jsonObject.put("requestMethod", operLog.opt("f_request_method"));
        jsonObject.put("operIp", operLog.opt("f_oper_ip"));
        jsonObject.put("operUrl", operLog.opt("f_oper_url"));
        jsonObject.put("operName", operLog.opt("f_oper_name"));
        jsonObject.put("operParam", operLog.opt("f_oper_param"));
        jsonObject.put("jsonResult", operLog.opt("f_json_result"));
        jsonObject.put("errorMsg", StringUtils.substring(e.getMessage(), 0, 8000));
        jsonObject.put("businessTitle", operLog.opt("f_title"));
        jsonObject.put("businessType", operLog.opt("f_business_type"));
        jsonObject.put("operatorType", operLog.opt("f_operator_type"));
        jsonObject.put("costTime", operLog.opt("f_cost_time"));

        String requestPath = liuLiUtil.getCloudUrl() + UPLOAD_ERROR_LOG_PATH;
        RestAsyncTools.post(requestPath, jsonObject);
    }
}

==> af-common-liuli-1.1.9.20-sources.jar: com/af/v4/system/common/liuli/service/LiuLiMonitorService.java <==
package com.af.v4.system.common.liuli.service;

import com.af.v4.system.common.core.constant.CacheConstants;
import com.af.v4.system.common.core.utils.ApplicationUtils;
import com.af.v4.system.common.liuli.utils.LiuLiUtil;
import com.af.v4.system.common.plugins.http.RestAsyncTools;
import com.af.v4.system.common.redis.RedisService;
import org.json.JSONObject;
import org.springframework.stereotype.Service;

/**
 * 琉璃-监控服务
 *
 * @author Mr.river
 */
@Service
public class LiuLiMonitorService {
    /**
     * 上报应用错误日志
     */
    private static final String UPLOAD_ERROR_LOG_PATH = "/liuli/logic/uploadErrorLog";

    private final LiuLiUtil liuLiUtil;
    private final RedisService redisService;
    private final ApplicationUtils applicationUtils;

    public LiuLiMonitorService(LiuLiUtil liuLiUtil, RedisService redisService, ApplicationUtils applicationUtils) {
        this.liuLiUtil = liuLiUtil;
        this.redisService = redisService;
        this.applicationUtils = applicationUtils;
    }

    /**
     * 上报错误日志
     */
    public void uploadLogicErrorLog(JSONObject operLog) {
        String tenantUUID = redisService.get(CacheConstants.TENANT_UUID_KEY);
        //调用琉璃中心需传递的参数
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("tenantUUID", tenantUUID);
        jsonObject.put("applicationName", applicationUtils.getApplicationName());
        jsonObject.put("environment", applicationUtils.getEnvType().getValue());
        jsonObject.put("method", operLog.opt("f_method"));
        jsonObject.put("requestMethod", operLog.opt("f_request_method"));
        jsonObject.put("operIp", operLog.opt("f_oper_ip"));
        jsonObject.put("operUrl", operLog.opt("f_oper_url"));
        jsonObject.put("operName", operLog.opt("f_oper_name"));
        jsonObject.put("operParam", operLog.opt("f_oper_param"));
        jsonObject.put("jsonResult", operLog.opt("f_json_result"));
        jsonObject.put("errorMsg", operLog.opt("f_error_msg"));
        jsonObject.put("businessTitle", operLog.opt("f_title"));
        jsonObject.put("businessType", operLog.opt("f_business_type"));
        jsonObject.put("operatorType", operLog.opt("f_operator_type"));
        jsonObject.put("costTime", operLog.opt("f_cost_time"));

        String requestPath = liuLiUtil.getCloudUrl() + UPLOAD_ERROR_LOG_PATH;
        RestAsyncTools.post(requestPath, jsonObject);
    }
}
